==> tuia-news-center-api-1.6.6.0-xt21-20181204.091427-3-sources.jar: cn/com/duiba/tuia/news/center/dto/pdd/GoodsOrderDto.java <==
package cn.com.duiba.tuia.news.center.dto.pdd;

import java.io.Serializable;
import java.util.Date;

/**
 * 功能描述：
 *
 * @Auther: xiaotian
 * @Date: 2018/11/29 16:55
 * @Description:
 */
public class GoodsOrderDto implements Serializable{
    private Long id;

    private String pid;

    private String orderSn;

    private Long goodsId;

    private Long money;

    private Long payTime;

    private Long verifyTime;

    private Integer goodsStatus;

    private String goodsName;

    private String goodsThumbnailUrl;

    private Long userId;

    private Long userUpId;

    private Long moneyOwn;

    private Long moneyUp;

    private Integer appSettleStatus;

    private Long promotionRate;

    private Long goodsPrice;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getPid() {
        return pid;
    }

    public void setPid(String pid) {
        this.pid = pid == null ? null : pid.trim();
    }

    public String getOrderSn() {
        return orderSn;
    }

    public void setOrderSn(String orderSn) {
        this.orderSn = orderSn == null ? null : orderSn.trim();
    }

    public Long getGoodsId() {
        return goodsId;
    }

    public void setGoodsId(Long goodsId) {
        this.goodsId = goodsId;
    }

    public Long getMoney() {
        return money;
    }

    public void setMoney(Long money) {
        this.money = money;
    }

    public Long getPayTime() {
        return payTime;
    }

    public void setPayTime(Long payTime) {
        this.payTime = payTime;
    }

    public Long getVerifyTime() {
        return verifyTime;
    }

    public void setVerifyTime(Long verifyTime) {
        this.verifyTime = verifyTime;
    }

    public Integer getGoodsStatus() {
        return goodsStatus;
    }

    public void setGoodsStatus(Integer goodsStatus) {
        this.goodsStatus = goodsStatus;
    }

    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName == null ? null : goodsName.trim();
    }

    public String getGoodsThumbnailUrl() {
        return goodsThumbnailUrl;
    }

    public void setGoodsThumbnailUrl(String goodsThumbnailUrl) {
        this.goodsThumbnailUrl = goodsThumbnailUrl == null ? null : goodsThumbnailUrl.trim();
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getUserUpId() {
        return userUpId;
    }

    public void setUserUpId(Long userUpId) {
        this.userUpId = userUpId;
    }

    public Long getMoneyOwn() {
        return moneyOwn;
    }

    public void setMoneyOwn(Long moneyOwn) {
        this.moneyOwn = moneyOwn;
    }

    public Long getMoneyUp() {
        return moneyUp;
    }

    public void setMoneyUp(Long moneyUp) {
        this.moneyUp = moneyUp;
    }

    public Integer getAppSettleStatus() {
        return appSettleStatus;
    }

    public void setAppSettleStatus(Integer appSettleStatus) {
        this.appSettleStatus = appSettleStatus;
    }

    public Long getPromotionRate() {
        return promotionRate;
    }

    public void setPromotionRate(Long promotionRate) {
        this.promotionRate = promotionRate;
    }

    public Long getGoodsPrice() {
        return goodsPrice;
    }

    public void setGoodsPrice(Long goodsPrice) {
        this.goodsPrice = goodsPrice;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-news-center-api-2.1.6.0-xt-20190619.032128-13-sources.jar: cn/com/duiba/tuia/news/center/dto/pdd/GoodsOrderDto.java <==
package cn.com.duiba.tuia.news.center.dto.pdd;

import java.io.Serializable;
import java.util.Date;

/**
 * 功能描述：
 *
 * @Auther: xiaotian
 * @Date: 2018/11/29 16:55
 * @Description:
 */
public class GoodsOrderDto implements Serializable{
    private Long id;

    private String pid;

    private String orderSn;

    private Long goodsId;

    private Long money;

    private Long payTime;

    private Long verifyTime;

    private Integer goodsStatus;

    private String goodsName;

    private String goodsThumbnailUrl;

    private Long userId;

    private Long userUpId;

    private Long moneyOwn;

    private Long moneyUp;

    private Integer appSettleStatus;

    private Long promotionRate;

    private Long goodsPrice;

    private Date gmtCreate;

    private Date gmtModified;

    /**
     * 创建队员
     */
    private String createMember;

    public String getCreateMember() {
        return createMember;
    }

    public void setCreateMember(String createMember) {
        this.createMember = createMember;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getPid() {
        return pid;
    }

    public void setPid(String pid) {
        this.pid = pid == null ? null : pid.trim();
    }

    public String getOrderSn() {
        return orderSn;
    }

    public void setOrderSn(String orderSn) {
        this.orderSn = orderSn == null ? null : orderSn.trim();
    }

    public Long getGoodsId() {
        return goodsId;
    }

    public void setGoodsId(Long goodsId) {
        this.goodsId = goodsId;
    }

    public Long getMoney() {
        return money;
    }

    public void setMoney(Long money) {
        this.money = money;
    }

    public Long getPayTime() {
        return payTime;
    }

    public void setPayTime(Long payTime) {
        this.payTime = payTime;
    }

    public Long getVerifyTime() {
        return verifyTime;
    }

    public void setVerifyTime(Long verifyTime) {
        this.verifyTime = verifyTime;
    }

    public Integer getGoodsStatus() {
        return goodsStatus;
    }

    public void setGoodsStatus(Integer goodsStatus) {
        this.goodsStatus = goodsStatus;
    }

    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName == null ? null : goodsName.trim();
    }

    public String getGoodsThumbnailUrl() {
        return goodsThumbnailUrl;
    }

    public void setGoodsThumbnailUrl(String goodsThumbnailUrl) {
        this.goodsThumbnailUrl = goodsThumbnailUrl == null ? null : goodsThumbnailUrl.trim();
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getUserUpId() {
        return userUpId;
    }

    public void setUserUpId(Long userUpId) {
        this.userUpId = userUpId;
    }

    public Long getMoneyOwn() {
        return moneyOwn;
    }

    public void setMoneyOwn(Long moneyOwn) {
        this.moneyOwn = moneyOwn;
    }

    public Long getMoneyUp() {
        return moneyUp;
    }

    public void setMoneyUp(Long moneyUp) {
        this.moneyUp = moneyUp;
    }

    public Integer getAppSettleStatus() {
        return appSettleStatus;
    }

    public void setAppSettleStatus(Integer appSettleStatus) {
        this.appSettleStatus = appSettleStatus;
    }

    public Long getPromotionRate() {
        return promotionRate;
    }

    public void setPromotionRate(Long promotionRate) {
        this.promotionRate = promotionRate;
    }

    public Long getGoodsPrice() {
        return goodsPrice;
    }

    public void setGoodsPrice(Long goodsPrice) {
        this.goodsPrice = goodsPrice;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
